pub struct BackgroundJobLogEntry {
pub apply_job_details: Option<ApplyJobDetails>,
pub completion_comment: Option<String>,
pub completion_state: Option<String>,
pub convert_job_details: Option<ConvertJobDetails>,
pub finish_time: Option<DateTime<Utc>>,
pub id: Option<String>,
pub import_rules_job_details: Option<ImportRulesJobDetails>,
pub job_type: Option<String>,
pub request_autocommit: Option<bool>,
pub seed_job_details: Option<SeedJobDetails>,
pub start_time: Option<DateTime<Utc>>,
}Expand description
Execution log of a background job.
This type is not used in any activity, and only used as part of another schema.
Fields
apply_job_details: Option<ApplyJobDetails>Output only. Apply job details.
completion_comment: Option<String>Output only. Job completion comment, such as how many entities were seeded, how many warnings were found during conversion, and similar information.
completion_state: Option<String>Output only. Job completion state, i.e. the final state after the job completed.
convert_job_details: Option<ConvertJobDetails>Output only. Convert job details.
finish_time: Option<DateTime<Utc>>The timestamp when the background job was finished.
id: Option<String>The background job log entry ID.
import_rules_job_details: Option<ImportRulesJobDetails>Output only. Import rules job details.
job_type: Option<String>The type of job that was executed.
request_autocommit: Option<bool>Output only. Whether the client requested the conversion workspace to be committed after a successful completion of the job.
seed_job_details: Option<SeedJobDetails>Output only. Seed job details.
start_time: Option<DateTime<Utc>>The timestamp when the background job was started.