pub struct GenerateTcpProxyScriptRequest {
pub vm_machine_type: Option<String>,
pub vm_name: Option<String>,
pub vm_subnet: Option<String>,
pub vm_zone: Option<String>,
}Expand description
Request message for ‘GenerateTcpProxyScript’ request.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
vm_machine_type: Option<String>Required. The type of the Compute instance that will host the proxy.
vm_name: Option<String>Required. The name of the Compute instance that will host the proxy.
vm_subnet: Option<String>Required. The name of the subnet the Compute instance will use for private connectivity. Must be supplied in the form of projects/{project}/regions/{region}/subnetworks/{subnetwork}. Note: the region for the subnet must match the Compute instance region.
vm_zone: Option<String>Optional. The Google Cloud Platform zone to create the VM in. The fully qualified name of the zone must be specified, including the region name, for example “us-central1-b”. If not specified, uses the “-b” zone of the destination Connection Profile’s region.