pub struct MappingRuleFilter {
pub entities: Option<Vec<String>>,
pub entity_name_contains: Option<String>,
pub entity_name_prefix: Option<String>,
pub entity_name_suffix: Option<String>,
pub parent_entity: Option<String>,
}Expand description
A filter defining the entities that a mapping rule should be applied to. When more than one field is specified, the rule is applied only to entities which match all the fields.
This type is not used in any activity, and only used as part of another schema.
Fields
entities: Option<Vec<String>>Optional. The rule should be applied to specific entities defined by their fully qualified names.
entity_name_contains: Option<String>Optional. The rule should be applied to entities whose non-qualified name contains the given string.
entity_name_prefix: Option<String>Optional. The rule should be applied to entities whose non-qualified name starts with the given prefix.
entity_name_suffix: Option<String>Optional. The rule should be applied to entities whose non-qualified name ends with the given suffix.
parent_entity: Option<String>Optional. The rule should be applied to entities whose parent entity (fully qualified name) matches the given value. For example, if the rule applies to a table entity, the expected value should be a schema (schema). If the rule applies to a column or index entity, the expected value can be either a schema (schema) or a table (schema.table)