pub struct PostgresDestinationConfig {
pub max_concurrent_connections: Option<i32>,
pub transaction_timeout: Option<Duration>,
}Expand description
Configuration for Postgres as a destination in a migration.
This type is not used in any activity, and only used as part of another schema.
Fields
max_concurrent_connections: Option<i32>Optional. Maximum number of connections Database Migration Service will open to the destination for data migration.
transaction_timeout: Option<Duration>Optional. Timeout for data migration transactions.