pub struct PrimaryInstanceSettings {
pub database_flags: Option<HashMap<String, String>>,
pub id: Option<String>,
pub instance_network_config: Option<InstanceNetworkConfig>,
pub labels: Option<HashMap<String, String>>,
pub machine_config: Option<MachineConfig>,
pub outbound_public_ip_addresses: Option<Vec<String>>,
pub private_ip: Option<String>,
}Expand description
Settings for the cluster’s primary instance
This type is not used in any activity, and only used as part of another schema.
Fields
database_flags: Option<HashMap<String, String>>Database flags to pass to AlloyDB when DMS is creating the AlloyDB cluster and instances. See the AlloyDB documentation for how these can be used.
id: Option<String>Required. The ID of the AlloyDB primary instance. The ID must satisfy the regex expression “[a-z0-9-]+”.
instance_network_config: Option<InstanceNetworkConfig>Optional. Metadata related to instance level network configuration.
labels: Option<HashMap<String, String>>Labels for the AlloyDB primary instance created by DMS. An object containing a list of ‘key’, ‘value’ pairs.
machine_config: Option<MachineConfig>Configuration for the machines that host the underlying database engine.
outbound_public_ip_addresses: Option<Vec<String>>Output only. All outbound public IP addresses configured for the instance.
private_ip: Option<String>Output only. The private IP address for the Instance. This is the connection endpoint for an end-user application.