pub struct ReverseSshConnectivity {
pub vm: Option<String>,
pub vm_ip: Option<String>,
pub vm_port: Option<i32>,
pub vpc: Option<String>,
}Expand description
The details needed to configure a reverse SSH tunnel between the source and destination databases. These details will be used when calling the generateSshScript method (see https://cloud.google.com/database-migration/docs/reference/rest/v1/projects.locations.migrationJobs/generateSshScript) to produce the script that will help set up the reverse SSH tunnel, and to set up the VPC peering between the Cloud SQL private network and the VPC.
This type is not used in any activity, and only used as part of another schema.
Fields
vm: Option<String>The name of the virtual machine (Compute Engine) used as the bastion server for the SSH tunnel.
vm_ip: Option<String>Required. The IP of the virtual machine (Compute Engine) used as the bastion server for the SSH tunnel.
vm_port: Option<i32>Required. The forwarding port of the virtual machine (Compute Engine) used as the bastion server for the SSH tunnel.
vpc: Option<String>The name of the VPC to peer with the Cloud SQL private network.