pub struct SqlServerSourceConfig {
pub cdc_start_position: Option<String>,
pub max_concurrent_cdc_connections: Option<i32>,
pub max_concurrent_full_dump_connections: Option<i32>,
pub skip_full_dump: Option<bool>,
}Expand description
Configuration for SQL Server as a source in a migration.
This type is not used in any activity, and only used as part of another schema.
Fields
cdc_start_position: Option<String>Optional. The log sequence number (LSN) to start CDC data migration from.
max_concurrent_cdc_connections: Option<i32>Optional. Maximum number of connections Database Migration Service will open to the source for CDC phase.
max_concurrent_full_dump_connections: Option<i32>Optional. Maximum number of connections Database Migration Service will open to the source for full dump phase.
skip_full_dump: Option<bool>Optional. Whether to skip full dump or not.