pub struct ValueTransformation {
pub apply_hash: Option<ApplyHash>,
pub assign_max_value: Option<Empty>,
pub assign_min_value: Option<Empty>,
pub assign_null: Option<Empty>,
pub assign_specific_value: Option<AssignSpecificValue>,
pub double_comparison: Option<DoubleComparisonFilter>,
pub int_comparison: Option<IntComparisonFilter>,
pub is_null: Option<Empty>,
pub round_scale: Option<RoundToScale>,
pub value_list: Option<ValueListFilter>,
}Expand description
Description of data transformation during migration as part of the ConditionalColumnSetValue.
This type is not used in any activity, and only used as part of another schema.
Fields
apply_hash: Option<ApplyHash>Optional. Applies a hash function on the data
assign_max_value: Option<Empty>Optional. Set to max_value - if integer or numeric, will use int.maxvalue, etc
assign_min_value: Option<Empty>Optional. Set to min_value - if integer or numeric, will use int.minvalue, etc
assign_null: Option<Empty>Optional. Set to null
assign_specific_value: Option<AssignSpecificValue>Optional. Set to a specific value (value is converted to fit the target data type)
double_comparison: Option<DoubleComparisonFilter>Optional. Filter on relation between source value and compare value of type double.
int_comparison: Option<IntComparisonFilter>Optional. Filter on relation between source value and compare value of type integer.
is_null: Option<Empty>Optional. Value is null
round_scale: Option<RoundToScale>Optional. Allows the data to change scale
value_list: Option<ValueListFilter>Optional. Value is found in the specified list.